@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # @summary
 #   Transform a supposed boolean to On or Off. Passes all other values through.
 #
@@ -17,8 +19,19 @@ Puppet::Functions.create_function(:'apache::bool2httpd') do
   #   apache::bool2httpd(undef) # returns 'Off'
   #
   def bool2httpd(arg)
-    return 'Off' if arg.nil? || arg == false || arg =~ %r{false}i || arg == :undef
-    return 'On' if arg == true || arg =~ %r{true}i
+    return 'Off' if arg.nil? || arg == false || matches_string?(arg, %r{false}i) || arg == :undef
+    return 'On' if arg == true || matches_string?(arg, %r{true}i)
+
     arg.to_s
   end
+
+  private
+
+  def matches_string?(value, matcher)
+    if Gem::Version.new(RUBY_VERSION) < Gem::Version.new('2.4.0')
+      value =~ matcher
+    else
+      value.is_a?(String) && value.match?(matcher)
+    end
+  end
 end
